/*----------------------------------------------------------------------------
 * Name:    7seg.c
 * Purpose: Low level 7Segment functions
 *----------------------------------------------------------------------------
 * This file is part of the uVision/ARM development tools.
 * This software may only be used under the terms of a valid, current,
 * end user licence from KEIL for a compatible version of KEIL software
 * development tools. Nothing else gives you the right to use this software.
 *
 * This software is supplied "AS IS" without warranties of any kind.
 *
 * Copyright (c) 2004-2013 KEIL - An ARM Company. All rights reserved.
 *----------------------------------------------------------------------------*/

#include "mb9bd10t.h"    // Device header
#include "7seg.h"


/*-----------------------------------------------------------------------------
 *      SevenSegment display: LED / Pin mapping
 *
 *                          0
 *                         --
 *                      5 |  |  1
 *                      4 |  |  2
 *                         -- . 7
 *                          3
 *
 *----------------------------------------------------------------------------*/



/*-----------------------------------------------------------------------------
 *      SevenSeg_Initialize:  Initialize SevenSegment Driver
 *
 * Parameters: (none)
 * Return:     (none)
 *----------------------------------------------------------------------------*/
void SevenSeg_Initialize(void)
{
  FM3_GPIO->DDR5  |= 0x00FF;
  FM3_GPIO->DDR7  |= 0x00FF;

  FM3_GPIO->PFR5  &= 0xFF00;
  FM3_GPIO->PFR7  &= 0xFF00;

  FM3_GPIO->PDOR5 |= 0x00ff;
  FM3_GPIO->PDOR7 |= 0x00ff;
}


/*-----------------------------------------------------------------------------
 *      SevenSeg_SetSegment:  Set or Clear a Segment
 *
 * Parameters: uint8_t block - Segment Block 0 or 1
 *             uint8_t num   - Segment Number
 *             uint8_t en    - enable or disable segment
 * Return:     (none)
 *----------------------------------------------------------------------------*/
void SevenSeg_SetSegment(uint8_t block, uint8_t num, uint8_t en)
{
  if(block) {
    if(en) FM3_GPIO->PDOR5 &= ~(1 << num);
    else   FM3_GPIO->PDOR5 |=  (1 << num);
  }
  else {
    if(en) FM3_GPIO->PDOR7 &= ~(1 << num);
    else   FM3_GPIO->PDOR7 |=  (1 << num);
  }
}

