/*----------------------------------------------------------------------------
 * Name:    LED.c
 * Purpose: Low level LED functions
 *----------------------------------------------------------------------------
 * This file is part of the uVision/ARM development tools.
 * This software may only be used under the terms of a valid, current,
 * end user licence from KEIL for a compatible version of KEIL software
 * development tools. Nothing else gives you the right to use this software.
 *
 * This software is supplied "AS IS" without warranties of any kind.
 *
 * Copyright (c) 2004-2013 KEIL - An ARM Company. All rights reserved.
 *----------------------------------------------------------------------------*/

#include "Board_LED.h" // Keil::Board Support:SK-FM3-176PMC-ETHERNET:LED
#include "7seg.h"      // Keil::Board Support:SK-FM3-176PMC-ETHERNET:7Segment



#define NUM_LEDS    7
#define SEGBLOCK0   0       // 7 Segment Block 0
#define SEGBLOCK1   1       // 7 Segment Block 1


/*-----------------------------------------------------------------------------
 *      LED_Initialize:  Initialize LEDs
 *
 * Parameters: (none)
 * Return:     (none)
 *----------------------------------------------------------------------------*/
int32_t LED_Initialize (void) {
  SevenSeg_Initialize();
  return 0;
}


/*-----------------------------------------------------------------------------
 *      LED_Uninitialize:  Uninitialize LEDs
 *
 * Parameters: (none)
 * Return:     (none)
 *----------------------------------------------------------------------------*/
int32_t LED_Uninitialize (void) {
  return 0;
}

/*-----------------------------------------------------------------------------
 *      LED_On: Turns on requested LED
 *
 * Parameters:  num - LED number
 * Return:     (none)
 *----------------------------------------------------------------------------*/
int32_t LED_On (uint32_t num) {
  SevenSeg_SetSegment(SEGBLOCK0, num, 1);
  return 0;
}

/*-----------------------------------------------------------------------------
 *       LED_Off: Turns off requested LED
 *
 * Parameters:  num - LED number
 * Return:     (none)
 *----------------------------------------------------------------------------*/
int32_t LED_Off (uint32_t num) {
  SevenSeg_SetSegment(SEGBLOCK0, num, 0);
  return 0;
}

/*-----------------------------------------------------------------------------
 *       LED_Out: Write value to LEDs
 *
 * Parameters:  val - value to be displayed on LEDs
 * Return:     (none)
 *----------------------------------------------------------------------------*/
int32_t LED_SetOut (uint32_t val) {
  uint32_t n;

  for (n = 0; n < NUM_LEDS; n++) {
    if (val & (1<<n)) {
      LED_On (n);
    } else {
      LED_Off(n);
    }
  }
  return 0;
}

/*-----------------------------------------------------------------------------
 *       LED_Num: Get number of available LEDs
 *
 * Parameters: (none)
 * Return:      number of available LEDs
 *----------------------------------------------------------------------------*/
uint32_t LED_Num (void) {
  return (NUM_LEDS);
}
